@@ -3,6 +3,7 @@ import asyncio
 from datetime import datetime
 from typing import List, Optional
 
+import pytz
 from aiokafka import AIOKafkaProducer
 from kafka.errors import UnknownTopicOrPartitionError, KafkaTimeoutError
 from patchwork.core import AsyncPublisher, Task
@@ -124,8 +125,8 @@ class AsyncKafkaPublisher(AsyncPublisher):
 
     async def _send(self, payload: bytes, task: Task, timeout: float = None):
         topic_name = task.meta.queue_name
-        if task.meta.HasField('not_before') and \
-                task.meta.not_before.ToDatetime() < datetime.now() and \
+        if task.meta.not_before and \
+                task.meta.not_before < datetime.now(pytz.UTC) and \
                 self.settings.postpone_queue_name:
             # put postponed tasks on the special queue, don't change task meta
             topic_name = self.settings.postpone_queue_name
@@ -134,15 +135,15 @@ class AsyncKafkaPublisher(AsyncPublisher):
         # parsing the task, might be useful on receiver side to filter messages faster,
         # or for debug purposes
         headers = [
-            ('id', task.uuid.encode()),
+            ('id', str(task.uuid).encode()),
             ('queue_name', task.meta.queue_name.encode()),
         ]
 
-        if task.meta.HasField('not_before'):
-            headers.append(('not_before', task.meta.not_bfore.ToSeconds().to_bytes(8, byteorder='big')))
+        if task.meta.not_before:
+            headers.append(('not_before', int(task.meta.not_before.timestamp()*1000).to_bytes(8, byteorder='big')))
 
-        if task.meta.HasField('expires'):
-            headers.append(('expires', task.meta.expires.ToSeconds().to_bytes(8, byteorder='big')))
+        if task.meta.expires:
+            headers.append(('expires', int(task.meta.expires.timestamp()*1000).to_bytes(8, byteorder='big')))
 
         if not topic_name:
             raise ValueError(f"Can't send task, no queue name defined")
