@@ -170,7 +170,7 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             'queue_name': meta.topic,
         })
 
-        task._kafka_subscriber = (meta.topic, meta.partition, meta.offset)
+        task._local['kafka_subscriber'] = (meta.topic, meta.partition, meta.offset)
         return task
 
     def _resume_partition(self, tp: TopicPartition):
@@ -186,9 +186,9 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         :param timeout:
         :return:
         """
-        assert hasattr(task, '_kafka_subscriber'), "cannot commit task not received by this subscriber"
-        tp = TopicPartition(task._kafka_subscriber[0], task._kafka_subscriber[1])
-        offset = task._kafka_subscriber[2]
+        assert 'kafka_subscriber' in task._local, "cannot commit task not received by this subscriber"
+        tp = TopicPartition(task._local['kafka_subscriber'][0], task._local['kafka_subscriber'][1])
+        offset = task._local['kafka_subscriber'][2]
 
         try:
             # commit message
@@ -206,9 +206,9 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
             self._resume_partition(tp)
 
     async def rollback(self, task: Task, timeout: float = None):
-        assert hasattr(task, '_kafka_subscriber'), "cannot commit task not received by this subscriber"
-        tp = TopicPartition(task._kafka_subscriber[0], task._kafka_subscriber[1])
-        offset = task._kafka_subscriber[2]
+        assert 'kafka_subscriber' in task._local, "cannot commit task not received by this subscriber"
+        tp = TopicPartition(task._local['kafka_subscriber'][0], task._local['kafka_subscriber'][1])
+        offset = task._local['kafka_subscriber'][2]
 
         # seek just before rollback message
         self.consumer.seek(tp, offset)
